"""
apps
"""

from django.apps import AppConfig


class FleetFinderConfig(AppConfig):
    """
    application config
    """

    name = "fleetfinder"
    label = "fleetfinder"
    verbose_name = "fleetfinder"
