{% load static %}

{% if avoid_cdn %}
    <link rel="stylesheet" type="text/css" href="{% static 'fleetfinder/libs/multi-select/0.9.12/css/multi-select.min.css' %}">
{% else %}
    <link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/multi-select/0.9.12/css/multi-select.min.css">
{% endif %}
