{% extends 'allianceauth/base.html' %}

{% load i18n %}

{% block page_title %}{% translate "Fleet Finder" %}{% endblock %}

{% block content %}
    <br />
    <div class="aa-fleetfinder">
        <nav class="navbar navbar-default">
            <div class="container-fluid">
                <div class="navbar-header">
                    <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                        <span class="sr-only">{% translate "Toggle navigation" %}</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>

                    <a class="navbar-brand" href="{% url 'fleetfinder:dashboard' %}">{% translate "Available Fleets" %}</a>
                </div>

                <ul class="nav navbar-nav">
                    {% if perms.fleet.manage %}
                        <li> <a href="{% url 'fleetfinder:create_fleet' %}">{% translate "Create Fleet" %}</a></li>
                    {% endif %}
                </ul>
            </div>
        </nav>

        {% block fleetfinder_block %}{% endblock %}
    </div>
{% endblock %}
