/* slim select
------------------------------------------------------------------------------------- */
@media all {
    .aa-fleetfinder .ss-main .ss-multi-selected .ss-add {
        margin: 17px;
    }

    .aa-fleetfinder .ss-main .ss-multi-selected {
        height: 45px;
    }

    .aa-fleetfinder .ss-main .ss-multi-selected .ss-values .ss-value {
        font-size: 14px;
    }

    .aa-fleetfinder .eve-character-portrait,
    .aa-fleetfinder .eve-type-icon {
        margin-right: 0.5rem;
    }

    .aa-fleetfinder .table-vertical-middle td {
        vertical-align: middle;
    }
}
